@@ -29,8 +29,9 @@ Running tests:
 """
 
 __title__ = 'fblib'
-__version__ = '0.9.2'
-__build__ = 0x0092
+__version__ = (0, 9, 3)
 __author__ = 'Kirill Karmadonov'
 __license__ = 'ISC'
 __copyright__ = 'Copyright 2012 Kirill Karmadonov'
+
+__all__ = ["core"]
